# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Net-Telnet
Summary:	Interact with TELNET port or other TCP ports
Version:	3.05
Release:	6.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/dist/Net-Telnet
Source0:	https://cpan.metacpan.org/modules/by-module/Net/Net-Telnet-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Exporter)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(Socket)
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(vars)
# Test Suite
# (no additional dependencies)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(IO::Socket::INET)

%description
Net::Telnet allows you to make client connections to a TCP port and do
network I/O, especially to a port using the TELNET protocol. Simple I/O
methods such as print, get, and getline are provided. More sophisticated
interactive features are provided because connecting to a TELNET port
ultimately means communicating with a program designed for human interaction.
These interactive features include the ability to specify a time-out and to
wait for patterns to appear in the input stream, such as the prompt from a
shell.

%prep
%setup -q -n Net-Telnet-%{version} 

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ChangeLog README
%{perl_vendorlib}/Net/
%{_mandir}/man3/Net::Telnet.3*

%changelog
* Tue Jul 18 2023 Paul Howarth <paul@city-fan.org> - 3.05-6
- Use SPDX-format license tag

* Mon Jun 21 2021 Paul Howarth <paul@city-fan.org> - 3.05-1
- Update to 3.05
  - Fixed some documentation and pod command typos
  - Stopped using the deprecated variable $[ in the autoflush idiom
    select((select($fh), $|=1)[$[])
  - Added a workaround for the "require FileHandle" bug in perl 5.10.1
  - Fixed a bug in new() that caused the instantiation to fail when setting one
    of the *_log input args to an empty string
  - Improved the speed of waitfor() to search for the "match", especially when
    reading a large amount of data, by using the dynamic arrays @- and @+
    instead of $` and $&
  - Changed the logging subroutines to also accept a tied filehandle
  - Fixed new perl warning about argument isn't numeric in numeric ge (>=)
- Switch upstream from search.cpan.org to metacpan.org

* Wed Apr 25 2018 Paul Howarth <paul@city-fan.org> - 3.04-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Tue Sep 13 2016 Paul Howarth <paul@city-fan.org> - 3.04-3
- Classify buildreqs by usage
- Simplify find command using -delete
- Drop %%defattr, redundant since rpm 4.4

* Sat Jul 13 2013 Paul Howarth <paul@city-fan.org> - 3.04-2
- Perl 5.18 rebuild

* Mon Apr 22 2013 Paul Howarth <paul@city-fan.org> - 3.04-1
- Update to 3.04
  - Added IPv6 support, enabled using the method/parameter family() and the
    installed Socket package version is 1.94+ (which corresponds with perl
    5.14 or later)
  - New methods (peerhost peerport sockhost sockport) to support IPv6, because
    the inherited ones from IO::Socket::INET don't
  - New methods (localhost localfamily) and open() parameters for binding to a
    local network interface
  - Methods fixed (dump_log, input_log, option_log, output_log) so they turn
    off logging when passed an empty string argument
  - Methods fixed (_fillbuf _put) to use Errno::EINTR, when possible, to test
    for an interrupted select(), sysread(), or syswrite(); the test for
    $! =~ /^interrupted doesn't work when LANG is not English
  - Methods fixed (dump_log, input_log, option_log, output_log) so they take a
    bare filehandle

* Sun Jun 10 2012 Paul Howarth <paul@city-fan.org> - 3.03-16
- BR: perl(Exporter) and perl(Socket)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 3.03-13
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Dec 22 2010 Paul Howarth <paul@city-fan.org> - 3.03-12
- Import from Fedora

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.03-11
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 3.03-10
- Mass rebuild with perl-5.12.0

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.03-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.03-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri May 23 2008 Fabio M. Di Nitto <fdinitto@redhat.com> - 3.03-7
- Fix bug 226273:
  - Add dist tag
  - Fix rpmlint errors for %%description
  - Remove MANIFEST from package
- General clean up of spec file

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 3.03-6.1
- Rebuild for new perl

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 3.03-5.1 
- Correct license tag
- Add BR: perl(ExtUtils::MakeMaker)

* Tue Jun 06 2006 Jason Vas Dias <jvdias@redhat.com> - 3.03-5
- Correct License: tag

* Wed Feb 15 2006 Jason Vas Dias <jvdias@redhat.com> - 3.03-4.3
- Fix bug 180591: correct URL: tag

* Fri Feb 03 2006 Jason Vas Dias <jvdias@redhat.com> - 3.03-4.2
- Rebuild for new perl-5.8.8
- Modify .spec file to conform to Fedora spectemplate-perl.spec

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- Rebuilt for new gcc

* Fri Dec 16 2005 Jesse Keating <jkeating@redhat.com>
- Rebuilt for new gcj

* Fri Feb 13 2004 Jonathan Brassow <jbrassow@redhat.com>
- Initial import
